@@ -6,3 +6,5 @@ __author__ = 'Alisue <lambdalisue@hashnote.net>'
 from permission.logics.base import PermissionLogic
 from permission.logics.author import AuthorPermissionLogic
 from permission.logics.collaborators import CollaboratorsPermissionLogic
+from permission.logics.groupin import GroupInPermissionLogic
+from permission.logics.staff import StaffPermissionLogic
