@@ -1,3 +1,5 @@
 from test_base import *
 from test_author import *
 from test_collaborators import *
+from test_groupin import *
+from test_staff import *
